summaryrefslogtreecommitdiffstatshomepage
path: root/src/devices/bus/ti99/peb/ti_fdc.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/devices/bus/ti99/peb/ti_fdc.h')
-rw-r--r--src/devices/bus/ti99/peb/ti_fdc.h18
1 files changed, 3 insertions, 15 deletions
diff --git a/src/devices/bus/ti99/peb/ti_fdc.h b/src/devices/bus/ti99/peb/ti_fdc.h
index 4c07bcb142e..ef16913e206 100644
--- a/src/devices/bus/ti99/peb/ti_fdc.h
+++ b/src/devices/bus/ti99/peb/ti_fdc.h
@@ -51,6 +51,7 @@ private:
DECLARE_WRITE_LINE_MEMBER(fdc_irq_w);
DECLARE_WRITE_LINE_MEMBER(fdc_drq_w);
+ DECLARE_WRITE_LINE_MEMBER(fdc_hld_w);
DECLARE_WRITE_LINE_MEMBER(dskpgena_w);
DECLARE_WRITE_LINE_MEMBER(kaclk_w);
@@ -65,17 +66,14 @@ private:
// Wait state logic
void operate_ready_line();
- // Set the current floppy
- void set_drive();
-
// Operate the floppy motors
void set_floppy_motors_running(bool run);
// Recent address
int m_address;
- // Holds the status of the DRQ and IRQ lines.
- int m_DRQ, m_IRQ;
+ // Holds the status of the DRQ, IRQ, and HLD lines.
+ int m_DRQ, m_IRQ, m_HLD;
// Latched CRU outputs
required_device<ls259_device> m_crulatch;
@@ -92,16 +90,6 @@ private:
// WD chip selected
bool m_WDsel;
- // Indicates which drive has been selected. Values are 0, 1, 2, and 4.
- // 000 = no drive
- // 001 = drive 1
- // 010 = drive 2
- // 100 = drive 3
- int m_DSEL;
-
- // Signal SIDSEL. 0 or 1, indicates the selected head.
- int m_SIDSEL;
-
// count 4.23s from rising edge of motor_on
emu_timer* m_motor_on_timer;